==> scummvm_1.9.0+dfsg.orig.tar.xz: scummvm-1.9.0/engines/titanic/game/gondolier/gondolier_slider.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#ifndef TITANIC_GONDOLIER_SLIDER_H
#define TITANIC_GONDOLIER_SLIDER_H

#include "titanic/game/gondolier/gondolier_base.h"

namespace Titanic {

class CGondolierSlider : public CGondolierBase {
	DECLARE_MESSAGE_MAP;
	bool MouseButtonDownMsg(CMouseButtonDownMsg *msg);
	bool MouseDragMoveMsg(CMouseDragMoveMsg *msg);
	bool EnterViewMsg(CEnterViewMsg *msg);
	bool MouseDragStartMsg(CMouseDragStartMsg *msg);
	bool StatusChangeMsg(CStatusChangeMsg *msg);
	bool MouseDragEndMsg(CMouseDragEndMsg *msg);
	bool IsHookedOnMsg(CIsHookedOnMsg *msg);
	bool FrameMsg(CFrameMsg *msg);
	bool SignalObject(CSignalObject *msg);
	bool ActMsg(CActMsg *msg);
private:
	int _fieldBC;
	int _fieldC0;
	int _fieldC4;
	int _fieldC8;
	Rect _sliderRect1;
	Rect _sliderRect2;
	int _arrayIndex;
	CString _string1;
	int _fieldFC;
	CString _string2;
	CString _string3;
	bool _field118;
public:
	CLASSDEF;
	CGondolierSlider();

	/**
	 * Save the data for the class to file
	 */
	virtual void save(SimpleFile *file, int indent);

	/**
	 * Load the data for the class from file
	 */
	virtual void load(SimpleFile *file);
};

} // End of namespace Titanic

#endif /* TITANIC_GONDOLIER_SLIDER_H */

==> scummvm_2.1.1+dfsg1.orig.tar.xz: scummvm-2.1.1/engines/titanic/game/gondolier/gondolier_slider.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#ifndef TITANIC_GONDOLIER_SLIDER_H
#define TITANIC_GONDOLIER_SLIDER_H

#include "titanic/game/gondolier/gondolier_base.h"

namespace Titanic {

class CGondolierSlider : public CGondolierBase {
	DECLARE_MESSAGE_MAP;
	bool MouseButtonDownMsg(CMouseButtonDownMsg *msg);
	bool MouseDragMoveMsg(CMouseDragMoveMsg *msg);
	bool EnterViewMsg(CEnterViewMsg *msg);
	bool MouseDragStartMsg(CMouseDragStartMsg *msg);
	bool StatusChangeMsg(CStatusChangeMsg *msg);
	bool MouseDragEndMsg(CMouseDragEndMsg *msg);
	bool IsHookedOnMsg(CIsHookedOnMsg *msg);
	bool FrameMsg(CFrameMsg *msg);
	bool SignalObject(CSignalObject *msg);
	bool ActMsg(CActMsg *msg);
private:
	Rect _rectUnused;
	Rect _thumbRect;
	Rect _defaultThumbRect;
	int _sliderIndex;
	CString _stringUnused;
	int _sliderNum;
	CString _armName;
	CString _signalTarget;
	bool _dragging;
public:
	CLASSDEF;
	CGondolierSlider();

	/**
	 * Save the data for the class to file
	 */
	virtual void save(SimpleFile *file, int indent);

	/**
	 * Load the data for the class from file
	 */
	virtual void load(SimpleFile *file);
};

} // End of namespace Titanic

#endif /* TITANIC_GONDOLIER_SLIDER_H */
